from sms.backends.base import BaseSMSBackend
import sms

class SMSBackend(BaseSMSBackend):
    """
    A SMS backend for use during test sessions.
    Stores all outgoing SMS's in sms.outbox rather than sending them.

    """
    def __init__(self, *args, **kwargs):
        super(SMSBackend, self).__init__(*args, **kwargs)
        if not hasattr(sms, 'outbox'):
            sms.outbox = []

    def send_sms(self, text, from_, to):
        sms.outbox.append({'text': text, 'from': from_, 'to': to})



import sys

from sms.backends.base import BaseSMSBackend

class SMSBackend(BaseSMSBackend):
    """
    Write SMS to console

    """
    def __init__(self):
        self.stream = sys.stdout

    def send_sms(self, text, from_, to):
        self.stream.write(to)
        self.stream.write(from_,)
        self.stream.write(text)
        self.stream.flush()



from django.conf import settings
from django.core.exceptions import ImproperlyConfigured
from django.utils.importlib import import_module

def import_backend(backend, **kwargs):

    path = backend

    try:
        mod_name, klass_name = path.rsplit('.', 1)
        mod = import_module(mod_name)
    except ImportError, e:
        raise ImproperlyConfigured(('Error importing SMS backend module %s: "%s"' % (mod_name, e)))

    try:
        klass = getattr(mod, klass_name)
    except AttributeError:
        raise ImproperlyConfigured(('Module "%s" does not define a '
                                    '"%s" class' % (mod_name, klass_name)))

    return klass(**kwargs)


def send_sms(text, from_, to, backend=None):
    """
    Send an SMS using the specified backend

    """
    import_backend(backend or settings.SMS_BACKEND).send_sms(text, from_, to)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
try:
    from setuptools import setup, find_packages
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup, find_packages

setup(
    name='django-sms',
    version='0.0.1',
    description='A Django app for sending SMS with interchangable backends.',
    author='Niels Sandholt Busch',
    author_email='niels.busch@gmail.com',
    url='https://bitbucket.org/resmio/django-sms/',
    long_description=open('README.rst', 'r').read(),
    packages=find_packages(),
    install_requires=['django>=1.3',],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Utilities'
    ],
)